#!/usr/bin/python

import os
import sys
import getopt
from mercurial import commands, ui, hg

def UpdateRepo(repoURL, targetDir, targetRevision="default"):
    if (os.path.exists(targetDir)):
        localRepo = hg.repository(ui.ui(), targetDir)
        print "Pulling latest changes from " + repoURL
        commands.pull(ui.ui(), localRepo, repoURL)
    else:
        commands.clone(ui.ui(), repoURL, targetDir)
        localRepo = hg.repository(ui.ui(), targetDir)
    
    commands.update(ui.ui(), localRepo, node=None, rev=targetRevision)
    
# Returns True/False for success/failure
def BuildOneProject(projectPath, targetName, configName, sdkName, buildDir):
    buildCommandLine = "xcodebuild -project %s -target \"%s\" -configuration %s -sdk %s SYMROOT=\"%s\"" % (projectPath, targetName, configName, sdkName, buildDir)
    print buildCommandLine
    return (os.system(buildCommandLine) == 0)

def DoBuild(buildDir=None, isIntegrationBuild=False):

    # default to within the directory itself, to avoid clashing
    if (buildDir == None):
        buildDir = os.path.realpath(".") + "/build"

    # Make sure we don't clash continuous integration builds with release and other builds
    if (isIntegrationBuild == True):
        buildDir = buildDir + "INTEGRATION"

    # check out our dependencies
    print "Updating local repositories"
    UpdateRepo("ssh://web.red-sweater.com/repos/RSCommon", "../RSCommon", "BlackInk1.2")


    # Make sure the basic app target builds as expected
    if (BuildOneProject("BlackInk.xcodeproj", "Black Ink", "Release", "macosx10.5", buildDir) != 0):
        print "BlackInk build failed."
        exit(1)

    # Do other builds only if we're doing integration testing
    if (isIntegrationBuild == True):
        if (BuildOneProject("BlackInk.xcodeproj", "UnitTests", "Release", "macosx10.5", buildDir) != 0):
            print "UnitTests build failed."
            exit(1)

    exit(0)

def usage():
    print "%s [-integration | -release] [-b <buildDirPath>]" % (sys.argv[0],)
    
def main(argv):                         
    try:                                
        opts, args = getopt.getopt(argv, "b:", ["buildDir=",]) 
    except getopt.GetoptError:           
        usage()                          
        sys.exit(2)                     

    buildDirPath = None
    isIntegrationBuild = False
    
    for opt, arg in opts:
        if (opt.startswith("-b")):
            buildDirPath = arg
        if (opt.startswith("-i")):
            isIntegrationBuild = True
    
    DoBuild(buildDirPath, isIntegrationBuild)
    
if __name__ == "__main__":
    main(sys.argv[1:])
